==> jc-1.4.0.tar.gz: javax/security/auth/PrivateCredentialPermission.h <==
// public final class javax.security.auth.PrivateCredentialPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 7c0b85726e5ec141 javax_security_auth_PrivateCredentialPermission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_javax_security_auth_PrivateCredentialPermission_H_
#define _JC_javax_security_auth_PrivateCredentialPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$sub_refs	_jc_javax_security_auth_PrivateCredentialPermission$sub_refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs	_jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$refs	_jc_javax_security_auth_PrivateCredentialPermission$refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$nonrefs	_jc_javax_security_auth_PrivateCredentialPermission$nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$object	_jc_javax_security_auth_PrivateCredentialPermission$object;

typedef struct _jc_javax_security_auth_PrivateCredentialPermission$fields_struct	_jc_javax_security_auth_PrivateCredentialPermission$fields_struct;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission$vmethods	_jc_javax_security_auth_PrivateCredentialPermission$vmethods;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission$vtable	_jc_javax_security_auth_PrivateCredentialPermission$vtable;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission$vtype	_jc_javax_security_auth_PrivateCredentialPermission$vtype;

// Class fields structure
struct _jc_javax_security_auth_PrivateCredentialPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_security_auth_PrivateCredentialPermission$fields_struct _jc_javax_security_auth_PrivateCredentialPermission$class_fields;

// Constructors
extern void _jc_javax_security_auth_PrivateCredentialPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_security_auth_PrivateCredentialPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission$method$getCredentialClass$44dfd76cf78c1c35(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
extern _jc_object_array *_jc_javax_security_auth_PrivateCredentialPermission$method$getPrincipals$736441c5b378f5c5(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
extern jint _jc_javax_security_auth_PrivateCredentialPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
extern jboolean _jc_javax_security_auth_PrivateCredentialPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_java_security_PermissionCollection$object *_jc_javax_security_auth_PrivateCredentialPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$getCredentialClass$44dfd76cf78c1c35;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$getPrincipals$736441c5b378f5c5;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_javax_security_auth_PrivateCredentialPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
	struct _jc_java_lang_String$object	*(*getCredentialClass$44dfd76cf78c1c35)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
	_jc_object_array	*(*getPrincipals$736441c5b378f5c5)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_security_Permission$object *);
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *);
};

// Vtable
struct _jc_javax_security_auth_PrivateCredentialPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_javax_security_auth_PrivateCredentialPermission$vmethods	javax_security_auth_PrivateCredentialPermission;
};

// Vtype
struct _jc_javax_security_auth_PrivateCredentialPermission$vtype {
	_jc_type			type;
	_jc_javax_security_auth_PrivateCredentialPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission$sub_refs {
	struct _jc_java_lang_String$object	*credentialClass;
	struct _jc_object	*principals;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission$refs {
    _jc_javax_security_auth_PrivateCredentialPermission$sub_refs	javax_security_auth_PrivateCredentialPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs {
	jboolean	testing;
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs	javax_security_auth_PrivateCredentialPermission;
};

// Object instance structure
struct _jc_javax_security_auth_PrivateCredentialPermission$object {
	_jc_javax_security_auth_PrivateCredentialPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_PrivateCredentialPermission$vtype	*vtype;
	_jc_javax_security_auth_PrivateCredentialPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_PrivateCredentialPermission$vtype _jc_javax_security_auth_PrivateCredentialPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_PrivateCredentialPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_PrivateCredentialPermission$class_object;

#endif	/* _JC_javax_security_auth_PrivateCredentialPermission_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/PrivateCredentialPermission.h <==
// public final class javax.security.auth.PrivateCredentialPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2377c76e79058a72 java_security_Permission
// @dep_class 7c0b85726e5ec141 javax_security_auth_PrivateCredentialPermission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_javax_security_auth_PrivateCredentialPermission_H_
#define _JC_javax_security_auth_PrivateCredentialPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$sub_refs	_jc_javax_security_auth_PrivateCredentialPermission$sub_refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs	_jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$refs	_jc_javax_security_auth_PrivateCredentialPermission$refs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$nonrefs	_jc_javax_security_auth_PrivateCredentialPermission$nonrefs;
typedef struct _jc_javax_security_auth_PrivateCredentialPermission$object	_jc_javax_security_auth_PrivateCredentialPermission$object;

typedef struct _jc_javax_security_auth_PrivateCredentialPermission$fields_struct	_jc_javax_security_auth_PrivateCredentialPermission$fields_struct;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission$vmethods	_jc_javax_security_auth_PrivateCredentialPermission$vmethods;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission$vtable	_jc_javax_security_auth_PrivateCredentialPermission$vtable;
typedef const struct _jc_javax_security_auth_PrivateCredentialPermission$vtype	_jc_javax_security_auth_PrivateCredentialPermission$vtype;

// Class fields structure
struct _jc_javax_security_auth_PrivateCredentialPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_security_auth_PrivateCredentialPermission$fields_struct _jc_javax_security_auth_PrivateCredentialPermission$class_fields;

// Constructors
extern void _jc_javax_security_auth_PrivateCredentialPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_security_auth_PrivateCredentialPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_PrivateCredentialPermission$method$getCredentialClass$44dfd76cf78c1c35(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_security_auth_PrivateCredentialPermission$method$getPrincipals$736441c5b378f5c5(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_security_auth_PrivateCredentialPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_security_auth_PrivateCredentialPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_PermissionCollection$object *_jc_javax_security_auth_PrivateCredentialPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$getCredentialClass$44dfd76cf78c1c35;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$getPrincipals$736441c5b378f5c5;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_javax_security_auth_PrivateCredentialPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_javax_security_auth_PrivateCredentialPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getCredentialClass$44dfd76cf78c1c35)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPrincipals$736441c5b378f5c5)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_javax_security_auth_PrivateCredentialPermission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_PrivateCredentialPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_javax_security_auth_PrivateCredentialPermission$vmethods	javax_security_auth_PrivateCredentialPermission;
};

// Vtype
struct _jc_javax_security_auth_PrivateCredentialPermission$vtype {
	_jc_type			type;
	_jc_javax_security_auth_PrivateCredentialPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission$sub_refs {
	struct _jc_java_lang_String$object	*credentialClass;
	struct _jc_object	*principals;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission$refs {
    _jc_javax_security_auth_PrivateCredentialPermission$sub_refs	javax_security_auth_PrivateCredentialPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs {
	jboolean	testing;
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_PrivateCredentialPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_javax_security_auth_PrivateCredentialPermission$sub_nonrefs	javax_security_auth_PrivateCredentialPermission;
};

// Object instance structure
struct _jc_javax_security_auth_PrivateCredentialPermission$object {
	_jc_javax_security_auth_PrivateCredentialPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_PrivateCredentialPermission$vtype	*vtype;
	_jc_javax_security_auth_PrivateCredentialPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_PrivateCredentialPermission$vtype _jc_javax_security_auth_PrivateCredentialPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_PrivateCredentialPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_PrivateCredentialPermission$class_object;

#endif	/* _JC_javax_security_auth_PrivateCredentialPermission_H_ */
